"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SecureConnection = exports.PlainConnection = exports.Connection = void 0;
var _net = require("net");
var _fs = require("fs");
var _tls = _interopRequireDefault(require("tls"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
class Connection {
  constructor(options, manager) {
    var _options$host, _options$port;
    _defineProperty(this, "socket", void 0);
    _defineProperty(this, "host", void 0);
    _defineProperty(this, "port", void 0);
    _defineProperty(this, "manager", void 0);
    this.manager = manager;
    this.host = (_options$host = options === null || options === void 0 ? void 0 : options.host) !== null && _options$host !== void 0 ? _options$host : '127.0.0.1';
    this.port = (_options$port = options === null || options === void 0 ? void 0 : options.port) !== null && _options$port !== void 0 ? _options$port : 28777;
  }
  socketOnError(error) {
    this.manager.emit('connection:error', error);
  }
  socketOnTimeout() {
    var _this$socket;
    this.manager.emit('connection:timeout', (_this$socket = this.socket) === null || _this$socket === void 0 ? void 0 : _this$socket.readyState);
  }
  socketOnConnect() {
    var _this$socket2;
    (_this$socket2 = this.socket) === null || _this$socket2 === void 0 ? void 0 : _this$socket2.setKeepAlive(true, 60 * 1000);
    this.manager.emit('connection:connected');
  }
  socketOnClose(error) {
    this.manager.emit('connection:closed', error);
  }
  addEventListeners(socket) {
    socket.once('error', this.socketOnError.bind(this));
    socket.once('timeout', this.socketOnTimeout.bind(this));
    socket.once('close', this.socketOnClose.bind(this));
  }
  close() {
    var _this$socket3, _this$socket4;
    (_this$socket3 = this.socket) === null || _this$socket3 === void 0 ? void 0 : _this$socket3.removeAllListeners();
    (_this$socket4 = this.socket) === null || _this$socket4 === void 0 ? void 0 : _this$socket4.destroy();
    this.manager.emit('connection:closed');
  }
  send(message) {
    var _this$socket5;
    (_this$socket5 = this.socket) === null || _this$socket5 === void 0 ? void 0 : _this$socket5.write(message);
  }
  readyToSend() {
    return this.socket && this.socket.readyState === 'open';
  }
  connect() {
    // Place Holder
  }
}
exports.Connection = Connection;
class PlainConnection extends Connection {
  connect() {
    this.socket = new _net.Socket();
    this.socket.connect(this.port, this.host);
    super.addEventListeners(this.socket);
    this.socket.on('connect', super.socketOnConnect.bind(this));
  }
}
exports.PlainConnection = PlainConnection;
class SecureConnection extends Connection {
  constructor(options, manager) {
    super(options, manager);
    _defineProperty(this, "secureContextOptions", void 0);
    this.secureContextOptions = SecureConnection.createSecureContextOptions(options);
  }
  static createSecureContextOptions(options) {
    const sslKey = options.ssl_key;
    const sslCert = options.ssl_cert;
    const ca = options.ca;
    const sslPassphrase = options.ssl_passphrase;
    const rejectUnauthorized = options.rejectUnauthorized;
    const secureContextOptions = {
      key: sslKey && (0, _fs.readFileSync)(sslKey),
      cert: sslCert && (0, _fs.readFileSync)(sslCert),
      passphrase: sslPassphrase || undefined,
      rejectUnauthorized: rejectUnauthorized,
      ca: ca && (0, _fs.readFileSync)(ca)
    };
    return secureContextOptions;
  }
  connect() {
    this.socket = _tls.default.connect(this.port, this.host, this.secureContextOptions);
    super.addEventListeners(this.socket);
    this.socket.on('secureConnect', super.socketOnConnect.bind(this));
  }
}
exports.SecureConnection = SecureConnection;